<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\CloudBuild;

class UploadedNpmPackage extends \Google\Model
{
  protected $fileHashesType = FileHashes::class;
  protected $fileHashesDataType = '';
  protected $pushTimingType = TimeSpan::class;
  protected $pushTimingDataType = '';
  /**
   * @var string
   */
  public $uri;

  /**
   * @param FileHashes
   */
  public function setFileHashes(FileHashes $fileHashes)
  {
    $this->fileHashes = $fileHashes;
  }
  /**
   * @return FileHashes
   */
  public function getFileHashes()
  {
    return $this->fileHashes;
  }
  /**
   * @param TimeSpan
   */
  public function setPushTiming(TimeSpan $pushTiming)
  {
    $this->pushTiming = $pushTiming;
  }
  /**
   * @return TimeSpan
   */
  public function getPushTiming()
  {
    return $this->pushTiming;
  }
  /**
   * @param string
   */
  public function setUri($uri)
  {
    $this->uri = $uri;
  }
  /**
   * @return string
   */
  public function getUri()
  {
    return $this->uri;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(UploadedNpmPackage::class, 'Google_Service_CloudBuild_UploadedNpmPackage');
